// ImageCache: A handy helper class to manage
// image loading for you.  The last thing you want
// to do is load images from an external source
// more times than strictly necessary.  That's
// *especially* true when the external source lies
// somewhere out in the internet.  So create an 
// instance of the ImageCache class:
//
//   ImageCache cache = new ImageCache();
//
// Then, any time you would use 
//
//   PImage img = loadImage( my_img_name );
//
// Instead use this:
//
//   PImage img = cache.getImage( my_img_name );
//
// The cache will check whether this image has been
// loaded at any point in the current run of the sketch.
// If so, it'll just give you back the copy that was
// already loaded instead of getting a new copy.

// You don't have to worry about how this class works
// on the inside.  You just have to know how to use
// the constructor and the getImage() method.

class ImageCache
{
  private HashMap<String,PImage> cache;
  
  ImageCache()
  {
    cache = new HashMap<String,PImage>();
  }
  
  PImage getImage( String fname_or_url )
  {
    if( cache.containsKey( fname_or_url ) ) {
      return cache.get( fname_or_url );
    } else {
      PImage img = loadImage( fname_or_url );
      cache.put( fname_or_url, img );
      return img;
    }
  }
}
